@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Mail::Message::Body::File;
-use vars '$VERSION';
-$VERSION = '3.003';
+package Mail::Message::Body::File;{
+our $VERSION = '3.016';
+}
 
 use base 'Mail::Message::Body';
 
+use strict;
+use warnings;
+
 use Mail::Box::Parser;
 use Mail::Message;
 
